@@ -23,7 +23,7 @@ import (
 	"time"
 
 	"github.com/prometheus/client_golang/prometheus/testutil"
-	"github.com/sirupsen/logrus"
+	"github.com/prometheus/common/promslog"
 	"github.com/stretchr/testify/assert"
 	"go.mongodb.org/mongo-driver/bson"
 
@@ -53,8 +53,8 @@ func TestCollStatsCollector(t *testing.T) {
 	ti := labelsGetterMock{}
 
 	collection := []string{"testdb.testcol_00", "testdb.testcol_01", "testdb.testcol_02"}
-	logger := logrus.New()
-	c := newCollectionStatsCollector(ctx, client, logger, false, ti, collection)
+	logger := promslog.New(&promslog.Config{})
+	c := newCollectionStatsCollector(ctx, client, logger, false, ti, collection, false)
 
 	// The last \n at the end of this string is important
 	expected := strings.NewReader(`
