@@ -19,6 +19,7 @@ package exporter
 import (
 	"context"
 	"fmt"
+	"log/slog"
 	"net/http"
 	_ "net/http/pprof"
 	"strconv"
@@ -27,7 +28,7 @@ import (
 
 	"github.com/prometheus/client_golang/prometheus"
 	"github.com/prometheus/client_golang/prometheus/promhttp"
-	"github.com/sirupsen/logrus"
+	"github.com/prometheus/common/promslog"
 	"go.mongodb.org/mongo-driver/mongo"
 
 	"github.com/percona/mongodb_exporter/exporter/dsn_fix"
@@ -37,7 +38,7 @@ import (
 type Exporter struct {
 	client                *mongo.Client
 	clientMu              sync.Mutex
-	logger                *logrus.Logger
+	logger                *slog.Logger
 	opts                  *Opts
 	lock                  *sync.Mutex
 	totalCollectionsCount int
@@ -45,19 +46,13 @@ type Exporter struct {
 
 // Opts holds new exporter options.
 type Opts struct {
-	// Only get stats for the collections matching this list of namespaces.
-	// Example: db1.col1,db.col1
-	CollStatsNamespaces    []string
-	CollStatsLimit         int
 	CompatibleMode         bool
 	DirectConnect          bool
 	ConnectTimeoutMS       int
 	DisableDefaultRegistry bool
 	DiscoveringMode        bool
 	GlobalConnPool         bool
-	ProfileTimeTS          int
 	TimeoutOffset          int
-	CurrentOpSlowTime      string
 
 	CollectAll               bool
 	EnableDBStats            bool
@@ -72,14 +67,20 @@ type Opts struct {
 	EnableProfile            bool
 	EnableShards             bool
 	EnableFCV                bool // Feature Compatibility Version.
+	EnablePBMMetrics         bool
 
 	EnableOverrideDescendingIndex bool
 
-	// Enable metrics for Percona Backup for MongoDB (PBM).
-	EnablePBMMetrics bool
+	// Only get stats for the collections matching this list of namespaces.
+	// Example: db1.col1,db.col1
+	CollStatsNamespaces    []string
+	CollStatsLimit         int
+	CollStatsEnableDetails bool
+	IndexStatsCollections  []string
+	CurrentOpSlowTime      string
+	ProfileTimeTS          int
 
-	IndexStatsCollections []string
-	Logger                *logrus.Logger
+	Logger *slog.Logger
 
 	URI      string
 	NodeName string
@@ -101,7 +102,8 @@ func New(opts *Opts) *Exporter {
 	}
 
 	if opts.Logger == nil {
-		opts.Logger = logrus.New()
+		promslogConfig := &promslog.Config{}
+		opts.Logger = promslog.New(promslogConfig)
 	}
 
 	ctx := context.Background()
@@ -116,7 +118,7 @@ func New(opts *Opts) *Exporter {
 	go func() {
 		_, err := exp.getClient(ctx)
 		if err != nil {
-			exp.logger.Errorf("Cannot connect to MongoDB: %v", err)
+			exp.logger.Error("Cannot connect to MongoDB", "error", err)
 		}
 	}()
 
@@ -135,12 +137,12 @@ func (e *Exporter) makeRegistry(ctx context.Context, client *mongo.Client, topol
 
 	nodeType, err := getNodeType(ctx, client)
 	if err != nil {
-		e.logger.Errorf("Registry - Cannot get node type : %s", err)
+		e.logger.Error("Registry - Cannot get node type", "error", err)
 	}
 
-	dbBuildInfo, err := retrieveMongoDBBuildInfo(ctx, client, e.logger.WithField("component", "buildInfo"))
+	dbBuildInfo, err := retrieveMongoDBBuildInfo(ctx, client, e.logger.With("component", "buildInfo"))
 	if err != nil {
-		e.logger.Warnf("Registry - Cannot get MongoDB buildInfo: %s", err)
+		e.logger.Warn("Registry - Cannot get MongoDB buildInfo", "error", err)
 	}
 
 	gc := newGeneralCollector(ctx, client, nodeType, e.opts.Logger)
@@ -192,7 +194,7 @@ func (e *Exporter) makeRegistry(ctx context.Context, client *mongo.Client, topol
 	if (len(e.opts.CollStatsNamespaces) > 0 || e.opts.DiscoveringMode) && e.opts.EnableCollStats && limitsOk && requestOpts.EnableCollStats {
 		cc := newCollectionStatsCollector(ctx, client, e.opts.Logger,
 			e.opts.DiscoveringMode,
-			topologyInfo, e.opts.CollStatsNamespaces)
+			topologyInfo, e.opts.CollStatsNamespaces, e.opts.CollStatsEnableDetails)
 		registry.MustRegister(cc)
 	}
 
@@ -229,8 +231,7 @@ func (e *Exporter) makeRegistry(ctx context.Context, client *mongo.Client, topol
 	}
 
 	if e.opts.EnableTopMetrics && nodeType != typeMongos && limitsOk && requestOpts.EnableTopMetrics {
-		tc := newTopCollector(ctx, client, e.opts.Logger,
-			e.opts.CompatibleMode, topologyInfo)
+		tc := newTopCollector(ctx, client, e.opts.Logger, topologyInfo)
 		registry.MustRegister(tc)
 	}
 
@@ -272,8 +273,13 @@ func (e *Exporter) getClient(ctx context.Context) (*mongo.Client, error) {
 		e.clientMu.Lock()
 		defer e.clientMu.Unlock()
 
-		// If client is already initialized, return it.
+		// If client is already initialized, and Ping is successful -- return it.
 		if e.client != nil {
+			err := e.client.Ping(ctx, nil)
+			if err != nil {
+				return nil, fmt.Errorf("cannot connect to MongoDB: %w", err)
+			}
+
 			return e.client, nil
 		}
 
@@ -299,22 +305,27 @@ func (e *Exporter) getClient(ctx context.Context) (*mongo.Client, error) {
 // run for hooking up custom HTTP servers.
 func (e *Exporter) Handler() http.Handler {
 	return http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
-		seconds, err := strconv.Atoi(r.Header.Get("X-Prometheus-Scrape-Timeout-Seconds"))
-		// To support older ones vmagents.
-		if err != nil {
-			seconds = 10
+		scrapeTimeoutHeader := r.Header.Get("X-Prometheus-Scrape-Timeout-Seconds")
+		seconds := 10.0
+
+		if scrapeTimeoutHeader != "" {
+			if parsedSeconds, err := strconv.ParseFloat(scrapeTimeoutHeader, 64); err == nil {
+				seconds = parsedSeconds
+			} else {
+				e.logger.Info("Invalid X-Prometheus-Scrape-Timeout-Seconds header", "error", err)
+			}
 		}
-		seconds -= e.opts.TimeoutOffset
+		seconds -= float64(e.opts.TimeoutOffset)
 
 		var client *mongo.Client
-		ctx, cancel := context.WithTimeout(r.Context(), time.Duration(seconds)*time.Second)
+		ctx, cancel := context.WithTimeout(r.Context(), time.Duration(seconds*float64(time.Second)))
 		defer cancel()
 
 		requestOpts := GetRequestOpts(r.URL.Query()["collect[]"], e.opts)
 
-		client, err = e.getClient(ctx)
+		client, err := e.getClient(ctx)
 		if err != nil {
-			e.logger.Errorf("Cannot connect to MongoDB: %v", err)
+			e.logger.Error("Cannot connect to MongoDB", "error", err)
 		}
 
 		if client != nil && e.getTotalCollectionsCount() <= 0 {
@@ -332,7 +343,7 @@ func (e *Exporter) Handler() http.Handler {
 				if client != nil {
 					err := client.Disconnect(ctx)
 					if err != nil {
-						e.logger.Errorf("Cannot disconnect client: %v", err)
+						e.logger.Error("Cannot disconnect client", "error", err)
 					}
 				}
 			}()
@@ -361,7 +372,7 @@ func (e *Exporter) Handler() http.Handler {
 		// Delegate http serving to Prometheus client library, which will call collector.Collect.
 		h := promhttp.HandlerFor(gatherers, promhttp.HandlerOpts{
 			ErrorHandling: promhttp.ContinueOnError,
-			ErrorLog:      e.logger,
+			ErrorLog:      newHTTPErrorLogger(e.logger),
 		})
 
 		h.ServeHTTP(w, r)
