@@ -22,14 +22,16 @@ import (
 	"net"
 	"net/http"
 	"net/http/httptest"
+	"os"
 	"strconv"
 	"strings"
 	"sync"
 	"testing"
 
 	"github.com/prometheus/client_golang/prometheus/testutil"
-	"github.com/sirupsen/logrus"
+	"github.com/prometheus/common/promslog"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
 	"github.com/percona/mongodb_exporter/internal/tu"
 )
@@ -78,7 +80,7 @@ func TestConnect(t *testing.T) {
 
 	//nolint:dupl
 	t.Run("Test per-request connection", func(t *testing.T) {
-		log := logrus.New()
+		log := promslog.New(&promslog.Config{})
 
 		exporterOpts := &Opts{
 			Logger:         log,
@@ -112,7 +114,7 @@ func TestConnect(t *testing.T) {
 
 	//nolint:dupl
 	t.Run("Test global connection", func(t *testing.T) {
-		log := logrus.New()
+		log := promslog.New(&promslog.Config{})
 
 		exporterOpts := &Opts{
 			Logger:         log,
@@ -151,7 +153,7 @@ func TestConnect(t *testing.T) {
 // replSetGetStatusCollector and it should return false since it wasn't registered.
 // Note: Two Collectors are considered equal if their Describe method yields the
 // same set of descriptors.
-// unregister will try to Describe to get the descriptors set and we are using
+// unregister will try to Describe to get the descriptors set, and we are using
 // DescribeByCollect so, in the logs, you will see an error:
 // msg="cannot get replSetGetStatus: replSetGetStatus is not supported through mongos"
 // This is correct. Collect is being executed to Describe and Unregister.
@@ -175,7 +177,7 @@ func TestMongoS(t *testing.T) {
 
 	for _, test := range tests {
 		exporterOpts := &Opts{
-			Logger:                 logrus.New(),
+			Logger:                 promslog.New(&promslog.Config{}),
 			URI:                    fmt.Sprintf("mongodb://%s/admin", net.JoinHostPort(hostname, test.port)),
 			DirectConnect:          true,
 			GlobalConnPool:         false,
@@ -197,6 +199,92 @@ func TestMongoS(t *testing.T) {
 	}
 }
 
+func generateKerberosConfigFile(t *testing.T) *os.File {
+	t.Helper()
+	kerberosHost, err := tu.IPForContainer("kerberos")
+	require.NoError(t, err)
+
+	config := fmt.Sprintf(`
+[libdefaults]
+    default_realm = PERCONATEST.COM
+    forwardable = true
+    dns_lookup_realm = false
+    dns_lookup_kdc = false
+    ignore_acceptor_hostname = true
+    rdns = false
+[realms]
+    PERCONATEST.COM = {
+        kdc_ports = 88
+        kdc = %s
+    }
+[domain_realm]
+    .perconatest.com = PERCONATEST.COM
+    perconatest.com = PERCONATEST.COM
+    %s = PERCONATEST.COM
+`, kerberosHost, kerberosHost)
+	configFile, err := os.Create(t.TempDir() + "/krb5.conf")
+	require.NoError(t, err)
+
+	_, err = configFile.WriteString(config)
+	require.NoError(t, err)
+
+	return configFile
+}
+
+func TestGSSAPIAuth(t *testing.T) {
+	logger := promslog.New(&promslog.Config{})
+
+	mongoHost, err := tu.IPForContainer("psmdb-kerberos")
+	require.NoError(t, err)
+
+	configFile := generateKerberosConfigFile(t)
+	require.NoError(t, err)
+	defer func() {
+		_ = configFile.Close()
+		t.Setenv("KRB5_CONFIG", "")
+	}()
+
+	t.Setenv("KRB5_CONFIG", configFile.Name())
+	ctx := context.Background()
+
+	username := "pmm-test%40PERCONATEST.COM"
+	password := "password1"
+	uri := fmt.Sprintf("mongodb://%s:%s@%s/?authSource=$external&authMechanism=GSSAPI",
+		username,
+		password,
+		net.JoinHostPort(mongoHost, "27017"),
+	)
+	exporterOpts := &Opts{
+		URI:            uri,
+		Logger:         logger,
+		CollectAll:     true,
+		GlobalConnPool: false,
+		DirectConnect:  true,
+	}
+
+	client, err := connect(ctx, exporterOpts)
+	assert.NoError(t, err)
+
+	e := New(exporterOpts)
+	nodeType, _ := getNodeType(ctx, client)
+	gc := newGeneralCollector(ctx, client, nodeType, e.opts.Logger)
+	r := e.makeRegistry(ctx, client, new(labelsGetterMock), *e.opts)
+
+	expected := strings.NewReader(`
+		# HELP mongodb_up Whether MongoDB is up.
+		# TYPE mongodb_up gauge
+		mongodb_up {cluster_role="mongod"} 1` + "\n")
+
+	filter := []string{
+		"mongodb_up",
+	}
+	err = testutil.CollectAndCompare(gc, expected, filter...)
+	require.NoError(t, err, "mongodb_up metric should be 1")
+
+	res := r.Unregister(gc)
+	assert.True(t, res)
+}
+
 func TestMongoUpMetric(t *testing.T) {
 	ctx := context.Background()
 
@@ -219,7 +307,7 @@ func TestMongoUpMetric(t *testing.T) {
 	for _, tc := range testCases {
 		t.Run(tc.clusterRole+"/"+tc.URI, func(t *testing.T) {
 			exporterOpts := &Opts{
-				Logger:           logrus.New(),
+				Logger:           promslog.New(&promslog.Config{}),
 				URI:              tc.URI,
 				ConnectTimeoutMS: 200,
 				DirectConnect:    true,
