@@ -24,7 +24,7 @@ import (
 
 	"github.com/AlekSi/pointer"
 	"github.com/prometheus/client_golang/prometheus/testutil"
-	"github.com/sirupsen/logrus"
+	"github.com/prometheus/common/promslog"
 	"github.com/stretchr/testify/assert"
 	"go.mongodb.org/mongo-driver/bson"
 	"go.mongodb.org/mongo-driver/bson/primitive"
@@ -64,7 +64,7 @@ func TestIndexStatsCollector(t *testing.T) {
 	}
 
 	collection := []string{"testdb.testcol_00", "testdb.testcol_01", "testdb.testcol_02"}
-	c := newIndexStatsCollector(ctx, client, logrus.New(), false, true, ti, collection)
+	c := newIndexStatsCollector(ctx, client, promslog.New(&promslog.Config{}), false, true, ti, collection)
 
 	// The last \n at the end of this string is important
 	expected := strings.NewReader(`
@@ -114,7 +114,7 @@ func TestDescendingIndexOverride(t *testing.T) {
 	}
 
 	collection := []string{"testdb.testcol_00", "testdb.testcol_01", "testdb.testcol_02"}
-	c := newIndexStatsCollector(ctx, client, logrus.New(), false, true, ti, collection)
+	c := newIndexStatsCollector(ctx, client, promslog.New(&promslog.Config{}), false, true, ti, collection)
 
 	// The last \n at the end of this string is important
 	expected := strings.NewReader(`
